==> everycomp-1.20-2.8.7-fabric-sources.jar: net/mehvahdjukaar/every_compat/api/CompatModule.java <==
package net.mehvahdjukaar.every_compat.api;

import com.google.common.base.Suppliers;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.mehvahdjukaar.every_compat.ECRegistry;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.dynamicpack.ClientDynamicResourcesHandler;
import net.mehvahdjukaar.moonlight.api.events.AfterLanguageLoadEvent;
import net.mehvahdjukaar.moonlight.api.misc.Registrator;
import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.mehvahdjukaar.moonlight.api.platform.PlatHelper;
import net.mehvahdjukaar.moonlight.api.platform.RegHelper;
import net.mehvahdjukaar.moonlight.api.resources.assets.LangBuilder;
import net.mehvahdjukaar.moonlight.api.resources.pack.ResourceGenTask;
import net.mehvahdjukaar.moonlight.api.set.BlockType;
import net.minecraft.class_1299;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import java.util.Collection;
import java.util.List;
import java.util.function.Consumer;
import java.util.function.Supplier;


public abstract class CompatModule {

    protected final String modId;
    protected final String modName;

    //EC or addon namespace
    private final String myNamespace;

    protected CompatModule(String modId, String myNamespace) {
        this.modId = modId;
        this.modName = PlatHelper.getModName(modId);
        this.myNamespace = myNamespace;
    }

    protected CompatModule(String modId) {
        this(modId, EveryCompat.MOD_ID);
    }

    public String getModId() {
        return modId;
    }

    public String getMyNamespace() {
        return myNamespace;
    }

    // readable name
    public String getModName() {
        return modName;
    }

    public abstract String shortenedId();

    @Override
    public String toString() {
        return "WoodGood: " + LangBuilder.getReadableName(modId) + " Module";
    }

    public class_2960 modRes(String string) {
        return new class_2960(modId, string);
    }

    public List<String> getAlreadySupportedMods() {
        return List.of();
    }

    public void onModInit() {
    }

    public void onModSetup() {
    }

    public void onClientInit() {
    }

    public void onClientSetup() {
    }

    public <T extends BlockType> void registerBlocks(Class<T> typeClass,
                                                     Registrator<class_2248> registry, Collection<T> types) {
    }

    public void registerItems(Registrator<class_1792> registry) {
    }

    public void registerTiles(Registrator<class_2591<?>> registry) {
    }

    public void registerEntities(Registrator<class_1299<?>> registry) {
    }


    //resource pack stuff
    public void addDynamicServerResources(Consumer<ResourceGenTask> executor) {
    }

    @Environment(EnvType.CLIENT)
    public void addDynamicClientResources(Consumer<ResourceGenTask> executor) {
    }

    @Environment(EnvType.CLIENT)
    public void registerBlockEntityRenderers(ClientHelper.BlockEntityRendererEvent event) {
    }

    public void addTranslations(ClientDynamicResourcesHandler clientDynamicResourcesHandler, AfterLanguageLoadEvent lang) {
    }

    public void registerBlockColors(ClientHelper.BlockColorEvent event) {
    }

    public void registerItemColors(ClientHelper.ItemColorEvent event) {
    }

    public void registerItemsToExistingTabs(RegHelper.ItemToTabEvent event) {
    }

    //utility functions

    protected final <T extends class_2248> Supplier<T> getModBlock(String id, Class<T> blockClass) {
        return memorize(id, class_7923.field_41175);
    }

    @Deprecated(forRemoval = true)
    protected final Supplier<class_1761> getModTab(String id) {
        return memorize(id, class_7923.field_44687);
    }

    protected final Supplier<class_2248> getModBlock(String id) {
        return getModBlock(id, class_2248.class);
    }

    protected final Supplier<class_1792> getModItem(String id) {
        return memorize(id, class_7923.field_41178);
    }

    protected final <B extends class_2586> Supplier<class_2591<B>> getModTile(String id, Class<B> tileEntityClass) {
        return memorize(id, class_7923.field_41181);
    }

    protected final Supplier<class_2591<class_2586>> getModTile(String id) {
        return getModTile(id, class_2586.class);
    }

    //how much crap this module has registered
    public abstract int bloatAmount();

    //used for creative tabs
    public <T extends BlockType> List<class_1792> getAllItemsOfType(T type) {
        return List.of();
    }


    public <T> Supplier<T> memorize(String id, class_2378<?> reg) {
        return Suppliers.memoize(() -> {
            try {
                return (T) reg.method_17966(modRes(id))
                        .orElseThrow();
            } catch (Throwable e) {
                throw new IllegalStateException("Could not find " + id + " in " + reg + ". This likely means that the reigstry entry was renamed in the original mod and EC needs updating. " +
                        "Either downgrade the mod " + this.modId + " or wait for an Every Compat update");
            }
        });
    }

    // Ec tab
    public class_5321<class_1761> getDedicatedTab() {
        return ECRegistry.MOD_TAB.getKey();
    }

    public abstract Collection<Class<? extends BlockType>> getAffectedTypes();

    //these have to be known in advance
    public String[] getServerResourcesNamespaces() {
        return new String[]{modId, myNamespace};
    }

    public String[] getClientResourcesNamespaces() {
        return new String[]{myNamespace};
    }

}

==> everycomp-1.20-2.9.6-fabric-sources.jar: net/mehvahdjukaar/every_compat/api/CompatModule.java <==
package net.mehvahdjukaar.every_compat.api;

import com.google.common.base.Suppliers;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.mehvahdjukaar.every_compat.ECRegistry;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.dynamicpack.ClientDynamicResourcesHandler;
import net.mehvahdjukaar.moonlight.api.events.AfterLanguageLoadEvent;
import net.mehvahdjukaar.moonlight.api.misc.Registrator;
import net.mehvahdjukaar.moonlight.api.platform.ClientHelper;
import net.mehvahdjukaar.moonlight.api.platform.PlatHelper;
import net.mehvahdjukaar.moonlight.api.platform.RegHelper;
import net.mehvahdjukaar.moonlight.api.resources.assets.LangBuilder;
import net.mehvahdjukaar.moonlight.api.resources.pack.ResourceGenTask;
import net.mehvahdjukaar.moonlight.api.set.BlockType;
import net.minecraft.class_1299;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7923;
import java.util.Collection;
import java.util.List;
import java.util.function.Consumer;
import java.util.function.Supplier;


public abstract class CompatModule {

    protected final String modId;
    protected final String modName; //redable name

    //EC or addon namespace
    private final String myNamespace;

    protected CompatModule(String modId, String myNamespace) {
        this.modId = modId;
        this.modName = PlatHelper.getModName(modId);
        this.myNamespace = myNamespace;
    }

    protected CompatModule(String modId) {
        this(modId, EveryCompat.MOD_ID);
    }

    public String getModId() {
        return modId;
    }

    public String getMyNamespace() {
        return myNamespace;
    }

    // readable name
    public String getModName() {
        return modName;
    }

    public abstract String shortenedId();

    @Override
    public String toString() {
        return "WoodGood: " + LangBuilder.getReadableName(modId) + " Module";
    }

    public class_2960 modRes(String string) {
        return new class_2960(modId, string);
    }

    public List<String> getAlreadySupportedMods() {
        return List.of();
    }

    public void onModInit() {
    }

    public void onModSetup() {
    }

    public void onClientInit() {
    }

    public void onClientSetup() {
    }

    public <T extends BlockType> void registerBlocks(Class<T> typeClass,
                                                     Registrator<class_2248> registry, Collection<T> types) {
    }

    public void registerItems(Registrator<class_1792> registry) {
    }

    public void registerTiles(Registrator<class_2591<?>> registry) {
    }

    public void registerEntities(Registrator<class_1299<?>> registry) {
    }


    //resource pack stuff
    public void addDynamicServerResources(Consumer<ResourceGenTask> executor) {
    }

    @Environment(EnvType.CLIENT)
    public void addDynamicClientResources(Consumer<ResourceGenTask> executor) {
    }

    @Environment(EnvType.CLIENT)
    public void registerBlockEntityRenderers(ClientHelper.BlockEntityRendererEvent event) {
    }

    public void addTranslations(ClientDynamicResourcesHandler clientDynamicResourcesHandler, AfterLanguageLoadEvent lang) {
    }

    public void registerBlockColors(ClientHelper.BlockColorEvent event) {
    }

    public void registerItemColors(ClientHelper.ItemColorEvent event) {
    }

    public void registerItemsToExistingTabs(RegHelper.ItemToTabEvent event) {
    }

    //utility functions

    protected final <T extends class_2248> Supplier<T> getModBlock(String id, Class<T> blockClass) {
        return memorize(id, class_7923.field_41175);
    }

    @Deprecated(forRemoval = true)
    protected final Supplier<class_1761> getModTab(String id) {
        return memorize(id, class_7923.field_44687);
    }

    protected final Supplier<class_2248> getModBlock(String id) {
        return getModBlock(id, class_2248.class);
    }

    protected final Supplier<class_1792> getModItem(String id) {
        return memorize(id, class_7923.field_41178);
    }

    protected final <B extends class_2586> Supplier<class_2591<B>> getModTile(String id, Class<B> tileEntityClass) {
        return memorize(id, class_7923.field_41181);
    }

    protected final Supplier<class_2591<class_2586>> getModTile(String id) {
        return getModTile(id, class_2586.class);
    }

    //how much crap this module has registered
    public abstract int bloatAmount();

    //used for creative tabs
    public <T extends BlockType> List<class_1792> getAllItemsOfType(T type) {
        return List.of();
    }


    public <T> Supplier<T> memorize(String id, class_2378<?> reg) {
        return Suppliers.memoize(() -> {
            try {
                return (T) reg.method_17966(modRes(id))
                        .orElseThrow();
            } catch (Throwable e) {
                throw new IllegalStateException("Could not find " + id + " in " + reg + ". This likely means that the reigstry entry was renamed in the original mod and EC needs updating. " +
                        "Either downgrade the mod " + this.modId + " or wait for an Every Compat update");
            }
        });
    }

    // Ec tab
    public class_5321<class_1761> getDedicatedTab() {
        return ECRegistry.MOD_TAB.getKey();
    }

    public abstract Collection<Class<? extends BlockType>> getAffectedTypes();

    //these have to be known in advance
    public String[] getServerResourcesNamespaces() {
        return new String[]{modId, myNamespace};
    }

    public String[] getClientResourcesNamespaces() {
        return new String[]{myNamespace};
    }

}
